//ライセンス情報はAgeOnフォルダのLISENCEフォルダを参照してください
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Drawing;

using nispi.controlclass;

namespace nispi.Analysis
{
    /*class AnalysisImageControls
    {
        public FormParts aiFormParts;
        public BrowserParts browserParts;

        public ButtonParts addressButtonParts;
        public ButtonParts thumbnailButtonParts;

        public ButtonParts addressBrowserButtonParts;
        public ButtonParts thumbnailBrowserButtonParts;

        public AnalysisImage0 analysisImageView;

        AnalysisImageControlsEvent analysisImageControlsEvent;

        public AnalysisImageControls(AnalysisImage0 analysisImageView)
        {
            this.analysisImageView = analysisImageView;

            aiFormParts = FormPartsManager.Pop();
            aiFormParts.Text = "画像抽出";
            aiFormParts.Name = "isPopUp";
            //aiFormParts.control.SuspendLayout();
            aiFormParts.Show();
            //サイズを決定
            aiFormParts.Size = new Size(Const.form.mainForm.Size.Width / 2, Const.form.mainForm.Size.Height / 2);//Const.form.boardListTabControlParts.Size;

            aiFormParts.control.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedSingle;

            if (MainFormConst.formShowStyle.NOW_TYPE.Equals("TYPE1") == true)
            {
                //amFormParts.Location = new Point(System.Windows.Forms.Cursor.Position.X - (amFormParts.Size.Width / 2),
                 //   System.Windows.Forms.Cursor.Position.Y - amFormParts.Size.Height - 5);
                aiFormParts.Location = Const.form.boardListTabControlParts.PointToScreen();
            }
            else if (MainFormConst.formShowStyle.NOW_TYPE.Equals("TYPE2") == true)
            {
                //amFormParts.Location = new Point(System.Windows.Forms.Cursor.Position.X - (amFormParts.Size.Width),
                //    System.Windows.Forms.Cursor.Position.Y + 5);
                aiFormParts.Location = Const.form.boardIndexTabControlParts.PointToScreen();
            }

            aiFormParts.Owner = Const.form.mainForm.GetControl();
            //aiFormParts.control.ResumeLayout();

            browserParts = BrowserCtrlManager.Pop();
            //browserParts.ownerForm = aiFormParts;
            browserParts.nonTextMenuOn = false;
            browserParts.textMenuOn = false;
            browserParts.Size = new Size(aiFormParts.Size.Width - 18, aiFormParts.Size.Height - 67);

            addressButtonParts = ButtonPartsManager.Pop();
            addressButtonParts.Location = new Point(10, 1);
            addressButtonParts.Name = "addressButtonParts";
            addressButtonParts.Text = "";
            addressButtonParts.Size = new Size(26, 26);
            addressButtonParts.SetToolTip("アドレスを表示");
            addressButtonParts.SetBitMap("address.png");

            thumbnailButtonParts = ButtonPartsManager.Pop();
            thumbnailButtonParts.Location = new Point(40, 1);
            thumbnailButtonParts.Name = "thumbnailButtonParts";
            thumbnailButtonParts.Size = new Size(26, 26);
            thumbnailButtonParts.SetToolTip("画像を表示");
            thumbnailButtonParts.SetBitMap("thumbnail.png");

            addressBrowserButtonParts = ButtonPartsManager.Pop();
            addressBrowserButtonParts.Location = new Point(80, 1);
            addressBrowserButtonParts.Name = "addressBrowserButtonParts";
            addressBrowserButtonParts.Size = new Size(26, 26);
            addressBrowserButtonParts.SetToolTip("ブラウザでアドレスを表示");
            addressBrowserButtonParts.Image = Resources.browser;

            thumbnailBrowserButtonParts = ButtonPartsManager.Pop();
            thumbnailBrowserButtonParts.Location = new Point(110, 1);
            thumbnailBrowserButtonParts.Name = "thumbnailBrowserButtonParts";
            thumbnailBrowserButtonParts.Size = new Size(26, 26);
            thumbnailBrowserButtonParts.SetToolTip("ブラウザで画像を表示");
            thumbnailBrowserButtonParts.SetBitMap("thumbnailbrowser.png");

            aiFormParts.AddControl(browserParts);

            aiFormParts.AddControl(addressButtonParts);
            aiFormParts.AddControl(thumbnailButtonParts);

            aiFormParts.AddControl(addressBrowserButtonParts);
            aiFormParts.AddControl(thumbnailBrowserButtonParts);

            analysisImageControlsEvent = new AnalysisImageControlsEvent(this.analysisImageView, this);

            aiFormParts.Update();
        }

        public void RemoveControls()
        {
            analysisImageControlsEvent.RemoveEvent();

            //タブに登録されているコントロールを全削除
            aiFormParts.RemoveAllCtrl();
            //aiFormParts.Update();
            //aiFormParts.control.SuspendLayout();
            aiFormParts.Name = "";

            aiFormParts.Hide();

            //コントロールを元に戻す
            FormPartsManager.Push(aiFormParts);

            BrowserCtrlManager.Push(browserParts);

            ButtonPartsManager.Push(addressButtonParts);
            ButtonPartsManager.Push(thumbnailButtonParts);

            ButtonPartsManager.Push(addressBrowserButtonParts);
            ButtonPartsManager.Push(thumbnailBrowserButtonParts);
            
            //aiFormParts.control.ResumeLayout();
        }
    }*/
}
